..
   Do not edit this .rst file directly — it’s generated programmatically.
   See doc/reference.sh.

==================================================
Module: ``ssh``
==================================================

`Leer en español </es/latest/reference/ssh.html>`_

- **get ssh port**

Return the cPanel server SSH port.

*Example*

.. code:: sh

    $ cpanel get ssh port

See a sample of the JSON result data at:
https://api.docs.cpanel.net/openapi/cpanel/operation/SSH-get_port/


